@@ -17,14 +17,15 @@ from .middleware import MiddlewareConfigurationDTO
 from .pubsub import PubSubConfigurationDTO
 from .pubsub.publisher import TopicsConfigurationT
 from .pubsub.subscription import SubscriptionsConfigurationT
+from .system import SystemConfigurationDTO
 
 
 class ConfigurationDTO(
     BaseModel,
     Generic[
-        SubscriptionsConfigurationT,
-        TopicsConfigurationT,
         MaleoClientsConfigurationT,
+        TopicsConfigurationT,
+        SubscriptionsConfigurationT,
     ],
 ):
     model_config = ConfigDict(arbitrary_types_allowed=True)
@@ -40,9 +41,10 @@ class ConfigurationDTO(
         ..., description="Middleware's configurations"
     )
     pubsub: PubSubConfigurationDTO[
-        SubscriptionsConfigurationT,
         TopicsConfigurationT,
+        SubscriptionsConfigurationT,
     ] = Field(..., description="PubSub's configurations")
+    system: SystemConfigurationDTO = Field(..., description="System's configurations")
 
 
 ConfigurationT = TypeVar("ConfigurationT", bound=ConfigurationDTO)
