@@ -5,7 +5,7 @@ from .subscription import SubscriptionsConfigurationT
 
 
 class PubSubConfigurationDTO(
-    BaseModel, Generic[SubscriptionsConfigurationT, TopicsConfigurationT]
+    BaseModel, Generic[TopicsConfigurationT, SubscriptionsConfigurationT]
 ):
     publisher: PublisherConfigurationDTO[TopicsConfigurationT] = Field(
         ...,
