@@ -2,7 +2,7 @@ import traceback as tb
 from typing import Dict, Optional, Tuple, Type, Union
 from uuid import UUID
 from maleo.soma.enums.logging import LogLevel
-from maleo.soma.schemas.authentication import Authentication
+from maleo.soma.schemas.authentication import Authentication, MandatoryAuthentication
 from maleo.soma.schemas.error import (
     ErrorSchema,
     BadRequestErrorSchema,
@@ -72,7 +72,7 @@ class Error(Exception):
             SystemOperationActionSchema,
         ],
         request_context: Optional[RequestContext],
-        authentication: Optional[Authentication],
+        authentication: Optional[Union[Authentication, MandatoryAuthentication]],
         resource: Optional[Resource] = None,
         details: OptionalAny = None,
     ) -> None:
@@ -271,7 +271,7 @@ def from_resource_http_request(
     operation_timestamp: OperationTimestamp,
     operation_action: AllResourceOperationAction,
     request_context: Optional[RequestContext],
-    authentication: Optional[Authentication],
+    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
     resource: Resource,
     logger: BaseLogger,
 ):
