@@ -15,7 +15,7 @@ from maleo.soma.enums.operation import (
 from maleo.soma.enums.secret import SecretFormat
 from maleo.soma.exceptions import NotFound, InternalServerError
 from maleo.soma.mappings.secret import FORMAT_TYPE_MAPPING
-from maleo.soma.schemas.authentication import Authentication
+from maleo.soma.schemas.authentication import Authentication, MandatoryAuthentication
 from maleo.soma.schemas.data import DataPair
 from maleo.soma.schemas.operation.system import SystemOperationActionSchema
 from maleo.soma.schemas.operation.context import (
@@ -84,7 +84,7 @@ class GoogleSecretManager(GoogleClientManager):
             credentials=self._credentials
         )
         completed_at = datetime.now(tz=timezone.utc)
-        SuccessfulSystemOperationSchema(
+        SuccessfulSystemOperationSchema[None](
             service_context=self._service_context,
             id=operation_id,
             context=self._operation_context,
@@ -111,7 +111,7 @@ class GoogleSecretManager(GoogleClientManager):
         value: bytes,
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Authentication] = None,
+        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
     ) -> CreateSingleResourceOperationResult[SecretDataSchema[bytes], None]: ...
     @overload
     def create(
@@ -120,7 +120,7 @@ class GoogleSecretManager(GoogleClientManager):
         value: str,
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Authentication] = None,
+        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
     ) -> CreateSingleResourceOperationResult[SecretDataSchema[str], None]: ...
     def create(
         self,
@@ -128,7 +128,7 @@ class GoogleSecretManager(GoogleClientManager):
         value: Union[bytes, str],
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Authentication] = None,
+        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
     ) -> CreateSingleResourceOperationResult[SecretDataSchema[Any], None]:
         if not isinstance(value, (bytes, str)):
             raise TypeError("Value type can only either be 'bytes' or 'str'")
@@ -244,7 +244,7 @@ class GoogleSecretManager(GoogleClientManager):
         version: str = "latest",
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Authentication] = None,
+        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
     ) -> ReadSingleResourceOperationResult[SecretDataSchema[bytes], None]: ...
 
     @overload
@@ -255,7 +255,7 @@ class GoogleSecretManager(GoogleClientManager):
         version: str = "latest",
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Authentication] = None,
+        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
     ) -> ReadSingleResourceOperationResult[SecretDataSchema[str], None]: ...
 
     def read(
@@ -265,7 +265,7 @@ class GoogleSecretManager(GoogleClientManager):
         version: str = "latest",
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Authentication] = None,
+        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
     ) -> ReadSingleResourceOperationResult[SecretDataSchema[Any], None]:
         operation_id = operation_id if operation_id is not None else uuid4()
         operation_action = ReadResourceOperationAction()
