@@ -3,7 +3,7 @@ from uuid import UUID
 from Crypto.PublicKey.RSA import RsaKey
 from httpx import Response
 from redis.asyncio.client import Redis
-from typing import Optional
+from typing import Optional, Union
 from maleo.soma.dtos.configurations.cache.redis import RedisCacheNamespaces
 from maleo.soma.dtos.configurations.client.maleo import MaleoClientConfigurationDTO
 from maleo.soma.enums.environment import Environment
@@ -14,7 +14,7 @@ from maleo.soma.managers.client.base import (
 )
 from maleo.soma.managers.client.http import HTTPClientManager
 from maleo.soma.managers.credential import CredentialManager
-from maleo.soma.schemas.authentication import Authentication
+from maleo.soma.schemas.authentication import Authentication, MandatoryAuthentication
 from maleo.soma.schemas.operation.context import (
     OperationContextSchema,
     OperationOriginSchema,
@@ -60,7 +60,7 @@ class MaleoClientService(ClientService):
         executed_at: datetime,
         operation_action: AllResourceOperationAction,
         request_context: Optional[RequestContext],
-        authentication: Optional[Authentication],
+        authentication: Optional[Union[Authentication, MandatoryAuthentication]],
         resource: Resource,
     ):
         """Handle HTTP error response and raise appropriate exception"""
