@@ -2,6 +2,7 @@ import os
 from contextlib import contextmanager
 from datetime import datetime, timezone
 from pydantic import ValidationError
+from typing import Union
 from uuid import UUID
 from sqlalchemy import MetaData, text
 from sqlalchemy.engine import Engine, create_engine
@@ -23,7 +24,7 @@ from maleo.soma.exceptions import (
     DatabaseError,
 )
 from maleo.soma.models.table import BaseTable
-from maleo.soma.schemas.authentication import Authentication
+from maleo.soma.schemas.authentication import Authentication, MandatoryAuthentication
 from maleo.soma.schemas.operation.context import generate_operation_context
 from maleo.soma.schemas.operation.system import (
     SuccessfulSystemOperationSchema,
@@ -70,7 +71,7 @@ class SessionManager:
                 bind=engine, expire_on_commit=False
             )
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema(
+            SuccessfulSystemOperationSchema[None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=operation_context,
@@ -110,7 +111,7 @@ class SessionManager:
         self,
         operation_id: UUID,
         request_context: RequestContext,
-        authentication: Authentication,
+        authentication: Union[Authentication, MandatoryAuthentication],
     ) -> Generator[Session, None, None]:
         """Reusable function for managing database sessions."""
         operation_context = generate_operation_context(
@@ -123,7 +124,7 @@ class SessionManager:
         )
         executed_at = datetime.now(tz=timezone.utc)
         session = self._sessionmaker()
-        SuccessfulSystemOperationSchema(
+        SuccessfulSystemOperationSchema[None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
@@ -204,7 +205,7 @@ class SessionManager:
         finally:
             session.close()  # Ensure session closes
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema(
+            SuccessfulSystemOperationSchema[None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=operation_context,
@@ -224,7 +225,7 @@ class SessionManager:
         self,
         operation_id: UUID,
         request_context: RequestContext,
-        authentication: Authentication,
+        authentication: Union[Authentication, MandatoryAuthentication],
     ) -> Generator[Session, None, None]:
         """Returns a generator that yields a SQLAlchemy session for dependency injection."""
         return self._session_handler(
@@ -238,7 +239,7 @@ class SessionManager:
         self,
         operation_id: UUID,
         request_context: RequestContext,
-        authentication: Authentication,
+        authentication: Union[Authentication, MandatoryAuthentication],
     ) -> Generator[Session, None, None]:
         """Context manager for manual session handling. Supports `with SessionManager.get() as session:`"""
         yield from self._session_handler(
@@ -264,7 +265,7 @@ class SessionManager:
         if self._sessionmaker is not None:
             self._sessionmaker.close_all()
 
-        SuccessfulSystemOperationSchema(
+        SuccessfulSystemOperationSchema[None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
@@ -321,7 +322,7 @@ class DatabaseManager:
             )
 
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema(
+            SuccessfulSystemOperationSchema[None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -363,7 +364,7 @@ class DatabaseManager:
         try:
             self._metadata.create_all(bind=self._engine)
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema(
+            SuccessfulSystemOperationSchema[None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -407,7 +408,7 @@ class DatabaseManager:
         )
 
         completed_at = datetime.now(tz=timezone.utc)
-        SuccessfulSystemOperationSchema(
+        SuccessfulSystemOperationSchema[None](
             service_context=self._service_context,
             id=operation_id,
             context=self._operation_context,
@@ -439,7 +440,7 @@ class DatabaseManager:
         self,
         operation_id: UUID,
         request_context: RequestContext,
-        authentication: Authentication,
+        authentication: Union[Authentication, MandatoryAuthentication],
     ) -> bool:
         """Check database connectivity by executing a simple query."""
         operation_action = SystemOperationActionSchema(
@@ -454,7 +455,7 @@ class DatabaseManager:
             ) as session:
                 session.execute(text("SELECT 1"))
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema(
+            SuccessfulSystemOperationSchema[None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -487,7 +488,7 @@ class DatabaseManager:
         if self._engine is not None:
             self._engine.dispose()
 
-        SuccessfulSystemOperationSchema(
+        SuccessfulSystemOperationSchema[None](
             service_context=self._service_context,
             id=operation_id,
             context=self._operation_context,
