@@ -108,7 +108,7 @@ class ServiceManager(Generic[ConfigurationT]):
             self._initialize_database_manager(operation_id=operation_id)
             self._initialize_publisher()
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema(
+            SuccessfulSystemOperationSchema[None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=operation_context,
@@ -287,7 +287,7 @@ class ServiceManager(Generic[ConfigurationT]):
             self.app.include_router(router)
 
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema(
+            SuccessfulSystemOperationSchema[None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=operation_context,
@@ -349,7 +349,7 @@ class ServiceManager(Generic[ConfigurationT]):
             self.loggers.database.dispose()
             self.loggers.middleware.dispose()
 
-        SuccessfulSystemOperationSchema(
+        SuccessfulSystemOperationSchema[None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
