@@ -3,12 +3,13 @@ import urllib.parse
 from pydantic import BaseModel, Field, field_validator
 from enum import StrEnum
 from typing import Generic, List, Optional, TypeVar
-from maleo.soma.constants import DATE_FILTER_PATTERN, SORT_COLUMN_PATTERN
+from maleo.soma.constants import DATE_FILTER_PATTERN, SORT_COLUMN_PATTERN, ALL_STATUSES
 from maleo.soma.enums.operation import ResourceOperationStatusUpdateType
 from maleo.soma.enums.sort import SortOrder
 from maleo.soma.schemas.filter import DateFilter
 from maleo.soma.schemas.sort import SortColumn
 from maleo.soma.types.base import (
+    ListOfDataStatuses as ListOfDataStatusesEnum,
     ListOfStrings,
     OptionalListOfDataStatuses as OptionalListOfDataStatusesEnum,
     OptionalListOfIntegers,
@@ -94,8 +95,16 @@ class DateFilters(BaseModel):
     date_filters: List[DateFilter] = Field([], description="Date filters to be applied")
 
 
+class ListOfDataStatuses(BaseModel):
+    statuses: ListOfDataStatusesEnum = Field(
+        ALL_STATUSES, description="Data's statuses."
+    )
+
+
 class OptionalListOfDataStatuses(BaseModel):
-    statuses: OptionalListOfDataStatusesEnum = Field(None, description="Data's status")
+    statuses: OptionalListOfDataStatusesEnum = Field(
+        None, description="Data's statuses. (Optional)"
+    )
 
 
 class OptionalListOfCodes(BaseModel):
