@@ -1,4 +1,4 @@
-from typing import Any, Generic, Literal
+from typing import Generic, Literal
 from maleo.soma.mixins.general import SuccessT
 from maleo.soma.enums.operation import OperationType
 from maleo.soma.schemas.error import (
@@ -9,6 +9,7 @@ from maleo.soma.schemas.operation.base import BaseOperationSchema
 from maleo.soma.schemas.operation.result import (
     AnyOperationResultMixin,
     NoOperationResultMixin,
+    OperationResultSchemaT,
     OptionalOperationResultMixin,
 )
 from .action import SystemOperationActionSchema
@@ -29,8 +30,9 @@ class FailedSystemOperationSchema(
 
 
 class SuccessfulSystemOperationSchema(
-    OptionalOperationResultMixin[Any],
+    OptionalOperationResultMixin[OperationResultSchemaT],
     NoErrorMixin,
     SystemOperationSchema[Literal[True]],
+    Generic[OperationResultSchemaT],
 ):
     success: Literal[True] = True
